===============
bluesky-widgets
===============

.. image:: https://img.shields.io/travis/bluesky/bluesky-widgets.svg
        :target: https://travis-ci.org/bluesky/bluesky-widgets

.. image:: https://img.shields.io/pypi/v/bluesky-widgets.svg
        :target: https://pypi.python.org/pypi/bluesky-widgets

.. image:: https://img.shields.io/codecov/c/github/bluesky/bluesky-widgets
        :target: https://codecov.io/gh/bluesky/bluesky-widgets

Toolbox of widgets for visualizing blueskying data

Installation
------------

Install bluesky-widgets with Qt support::

    $ pip install bluesky-widgets[pyside2]

or::

    $ pip install bluesky-widgets[pyqt5]

Install bluesky-widgets with jupyter support::

    $ pip install bluesky-widgets[jupyter]

Install bluesky-widgets with all optional dependencies::

    $ pip install bluesky-widgets[complete]